// Hartman (2012) "Toll Booths on the Information Superhighway?" Study 1 
// Experimental Design: 2 (policy statement: metaphor vs. literal) between-subjects design

//*** STUDY DEMOGRAPHICS
// [genderD] where 1 = male, 2 = female
gen genderD = Q37

// [ageD]
gen ageD = 2007-Q38
sum ageD, det

// [raceD] where 1 = Black, 2 = Native Am./ Pacific Islander, 3 = Asian, 4 = White, 5 = Hispanic
gen raceD = Q39
sum raceD, det

// [partyD]: 7-point NES Party ID, where 1, 2, 3 = Rep., 4 = Ind., 5, 6, 7 = Dem.
tab Q32
gen partyD = 999
replace partyD = 1 if Q32==1 & Q33==1 
replace partyD = 2 if Q32==1 & Q33==2
replace partyD = 3 if Q32==3 & Q35==1
replace partyD = 3 if Q32==4 & Q35==1
replace partyD = 4 if Q32==3 & Q35==2
replace partyD = 4 if Q32==4 & Q35==2
replace partyD = 5 if Q32==3 & Q35==3
replace partyD = 5 if Q32==4 & Q35==3
replace partyD = 6 if Q32==2 & Q34==1
replace partyD = 7 if Q32==2 & Q34==2
tab partyD
replace partyD = . if partyD==999
sum partyD, det

// [ideologyD] Higher numbers = more liberal
gen ideologyD = Q36
sum ideologyD, det

//*** SUMMARY DEMOGRAPHICS
tab genderD
tab raceD
tab partyD
tab ideologyD
sum ageD partyD ideologyD, det


//*** INDEPENDENT VARIABLES
// [met] Metaphor Condition, where 1 = Metaphor, 0 = Literal 
gen met = 999
replace met = 1 if CheckM_1==1
replace met = 0 if CheckL_1==1
tab met
sum met

// [soph] Political Sophistication, where higher #'s = greater sophistication
sum Q17-Q24
recode Q17 (1=0)(2=0)(3=1)(4=0)(.=0), gen(s1)
recode Q18 (1=1)(2=0)(3=0)(4=0)(.=0), gen(s2)
recode Q19 (1=0)(2=0)(3=0)(4=1)(5=0)(.=0), gen(s3)
recode Q20 (1=0)(2=0)(3=0)(4=1)(5=0)(6=0)(7=0)(8=0)(.=0), gen(s4)
recode Q21 (1=0)(2=1)(3=0)(4=0)(.=0), gen(s5)
gen s6 = 1 if Q22==9
replace s6 = 0 if (Q22~=9 & Q22~=.) | Q22==.
recode Q23 (1=1)(2=0)(3=0)(4=0)(5=0)(.=0), gen(s7)
recode Q24 (1=0)(2=0)(3=1)(4=0)(.=0), gen(s8)
sum s1-s8
alpha s1-s8, item
kr20 s1-s8

tab s1
tab s2
tab s3
tab s4
tab s5
tab s6
tab s7
tab s8

gen so = s1 + s2 + s3 + s4 + s5 + s6 + s7 + s8
gen sophL = so/8
tab sophL

egen sop = mean(sophL)
gen sophM = sophL - sop
tab sophM

gen sophH = sophL - 1
tab sophH

// Controls
// [party] 7-point NES measure (0 to 1, mean centered), where higher #'s = more democratic
gen part = 999
replace part = 1 if Q32==1 & Q33==1 
replace part = 2 if Q32==1 & Q33==2
replace part = 3 if Q32==3 & Q35==1
replace part = 3 if Q32==4 & Q35==1
replace part = 4 if Q32==3 & Q35==2
replace part = 4 if Q32==4 & Q35==2
replace part = 5 if Q32==3 & Q35==3
replace part = 5 if Q32==4 & Q35==3
replace part = 6 if Q32==2 & Q34==1
replace part = 7 if Q32==2 & Q34==2
tab part
replace part = . if part==999
sum part, det

gen parti = (part - 1)/6
egen partM = mean(parti)
gen party = parti - partM 
sum party

// [ideology] 7-point NES measure (0 to 1, mean centered), where higher #'s = more liberal
gen ideolog = (Q36 - 1)/6
egen ideologyM = mean(ideolog)
gen ideology = ideolog - ideologyM
sum ideology

// [compint] 4-point Computer Interest (0 to 1, mean centered), where higher #'s = more interest
recode Q25 (1=4)(2=3)(3=2)(4=1), gen (compi)
gen compin = (compi - 1)/3
egen compinM = mean(compin)
gen compint = compin-compinM
sum compint

// [compknow] 4-point Computer Knowledge (0 to 1, mean centered), where higher #'s = more expertise
gen compk = (Q26 - 1)/3
egen compkM = mean(compk)
gen compknow = compk-compkM
sum compknow

// [nnknow] Dummy variable of NN Knowledge, where 1 = knowledge
recode Q1 (2=0), gen(nnknow)

// [female] Dummy Variable
gen female = 1 if Q37==2
replace female = 0 if Q37==1
sum female

// [nonwhite] Dummy Variable, where white is the baseline
recode Q39(1=1)(2=1)(3=1)(4=0)(5=1), gen (nonwhite)
tab nonwhite


//*** DEPENDENT VARIABLES
// [dv] Policy Attitude, 4-item semantic differential scale
alpha Q4 Q5 Q6 Q7, item

alpha Q4 Q5 Q6 Q7, gen(d1)
gen dv = (d1 - 1.5)/7.5
sum dv, det
tab dv

//*** SUMMARY STATISTICS OF KEY VARIABLES
sum dv quality anger fear met sophM party ideology compint compknow female, det
tabstat dv quality anger fear met sophM party ideology compint compknow female asian black hispanic, statistics (mean sd min max count) col (statistics) long
//latab

//*** ANALYSES
// Simple Regression
reg dv met sophM nnknow compknow compint party ideology female nonwhite

// Interactions
gen mXsL = met*sophL
gen mXsM = met*sophM
gen mXsH = met*sophH

//** Moderated Regression (by Political Sophistication)
reg dv met sophM mXsM nnknow compknow compint party ideology female nonwhite

//**Metaphor Slope at Each Level of Sophistication
reg dv met sophL mXsL nnknow compknow compint party ideology female nonwhite
reg dv met sophM mXsM nnknow compknow compint party ideology female nonwhite
reg dv met sophH mXsH nnknow compknow compint party ideology female nonwhite

//**Predicted Values
reg dv met sophL mXsL nnknow compknow compint party ideology female nonwhite
prvalue, x(met=0 sophL=0 mXsL=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(met=1 sophL=0 mXsL=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(met=0 sophL=.6173664 mXsL=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(met=1 sophL=.6173664 mXsL=.6173664 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(met=0 sophL=1 mXsL=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(met=1 sophL=1 mXsL=1 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)


// FIGURE 1: Effect of Policy Metaphor on Attitudes (Predicted Values)
gen var1 = met
gen var2 = sophL
gen inter1 = met*sophL

reg dv var1 nnknow compknow compint party ideology female nonwhite var2 inter1

* create "yhat1", predicted values at minimum [Literal]
replace inter1 = var2 * 0
postgr3 var2, x(var1 = 0) asis(var2 inter1) gen(yhat1)
label variable yhat1 "Literal"
label variable var2 "Political Sophistication"

* create "yhat2", predicted values at maximum [Metaphor]
replace inter1 = var2 * 1
postgr3 sophL, x(var1 = 1) asis(var2 inter1) gen(yhat2)
label variable yhat2 "Metaphor"

* show graph of regression lines
scatter yhat1 yhat2 var2, msymbol(+ O) c(l l) ylabel(0(.25).75) ytitle("Predicted Policy Support") name(graph1, replace)
drop  var1 var2 inter1 yhat1 yhat2


//*** GRAPHS with new dataset
use "Study_1_Graph.dta", clear

// Basic Graph (Graph Command)
graph bar val, over(met) over(soph)
// With Color (Graph)
graph bar val, over(met) over(soph) asyvars
// With Error Bars (TwoWay commmand)
graph twoway (bar val met) (rcap hi95 lo05 met), by(sophmet)
// Create Combined Variable
gen sophmet = met if soph == 0
replace  sophmet = met+3  if soph == 1
replace  sophmet = met+6  if soph == 2
sort sophmet
list sophmet soph met, sepby(soph)
// Graph of New Combined Variable (Twoway)
twoway (bar val sophmet)
// With Error Bars (Twoway)
twoway (bar val sophmet) (rcap hi95 lo95 sophmet)
// With Color (Twoway)
twoway (bar val sophmet if met==0) ///
       (bar val sophmet if met==1) ///
       (rcap hi95 lo95 sophmet)

// With Legend Labels (Twoway) **Reversed the Plot so that Metaphors are BLUE
twoway (bar val sophmet if met==1) ///
       (bar val sophmet if met==0) ///
       (rcap hi95 lo95 sophmet), ///
       legend(label(2 "Metaphor Message")label(1 "Literal Message")) ///
       legend( order(2 1)) ///
       xlabel( .5 "Low Sophistication" 3.5 "Mean Sophistication" 6.5 "High Sophistication", noticks) ///
       xtitle("") ///
       ylabel(.20(.10).80) ytitle("Predicted Policy Support")

findit graph2tex
graph2tex, epsfile(Study1)
