// Network Neutrality Study 2 (Adult Sample)
// 3 (policy statement: metaphor, literal, control) between-subjects design

set more off

//*** STUDY DEMOGRAPHICS
// How many different U.S. states? Most come from CA & NY
tab Q28

// [genderD] where 1 = male, 2 = female
gen genderD = Q27

// [ageD]
gen ageD = 2007-Q29
sum ageD, det

// [raceD] where 1 = Black, 2 = Native Am./ Pacific Islander, 3 = Asian, 4 = White, 5 = Hispanic
gen raceD = Q31
sum raceD, det

// [educD] where 1 = No HS, 2 = HS Dipl., 3 = AA, 4 = BA, 5 = Grad Degree
gen educD = Q30
sum educD, det

// [partyD]: 7-point NES Party ID, where 1, 2, 3 = Rep., 4 = Ind., 5, 6, 7 = Dem.
tab Q22
gen partyD = 999
replace partyD = 1 if Q22==1 & Q23==1 
replace partyD = 2 if Q22==1 & Q23==2
replace partyD = 3 if Q22==3 & Q25==1
replace partyD = 3 if Q22==4 & Q25==1
replace partyD = 4 if Q22==3 & Q25==2
replace partyD = 4 if Q22==4 & Q25==2
replace partyD = 5 if Q22==3 & Q25==3
replace partyD = 5 if Q22==4 & Q25==3
replace partyD = 6 if Q22==2 & Q24==1
replace partyD = 7 if Q22==2 & Q24==2
tab partyD
replace partyD = . if partyD==999
sum partyD, det

// [ideologyD] Higher numbers = more liberal
gen ideologyD = Q26
sum ideologyD, det

//*** SUMMARY DEMOGRAPHICS
tab genderD
tab raceD
tab educD
tab partyD
tab ideologyD
sum ageD partyD ideologyD, det


//*** INDEPENDENT VARIABLES
// [met] Metaphor Condition, where 1 = Metaphor, 0 = Literal & Control
gen met = 999
replace met = 1 if PM_1==1
replace met = 0 if PL_1==1 | CNTL_1==1
tab met
sum met

// [lit] Literal Condition, where 1 = Literal, 0 = Met & Control 
gen lit = 999
replace lit = 1 if PL_1==1
replace lit = 0 if PM_1==1 | CNTL_1==1
tab lit
sum lit

// [control] Control Condition, where 1 = Control, 0 = Met & Lit 
gen control = 999
replace control = 1 if CNTL_1==1
replace control = 0 if PM_1==1 | PL_1==1
tab control 
sum control

// [soph] Political Sophistication, where higher #'s = greater sophistication
sum Q12-Q19
recode Q12 (1=0)(2=0)(3=1)(4=0)(.=0), gen(s1)
recode Q13 (1=1)(2=0)(3=0)(4=0)(.=0), gen(s2)
recode Q14 (1=0)(2=0)(3=0)(4=1)(5=0)(.=0), gen(s3)
recode Q15 (1=0)(2=0)(3=0)(4=1)(5=0)(6=0)(7=0)(8=0)(.=0), gen(s4)
recode Q16 (1=0)(2=1)(3=0)(4=0)(.=0), gen(s5)
gen s6 = 1 if Q17==9
replace s6 = 0 if (Q17~=9 & Q17~=.) | Q17==.
recode Q18 (1=1)(2=0)(3=0)(4=0)(5=0)(.=0), gen(s7)
recode Q19 (1=0)(2=0)(3=1)(4=0)(.=0), gen(s8)
sum s1-s8
alpha s1-s8, item
kr20 s1-s8

tab s1
tab s2
tab s3
tab s4
tab s5
tab s6
tab s7
tab s8

// CORRECTED
gen so = s1 + s2 + s3 + s4 + s5 + s6 + s7 + s8
gen sophL = (so-1)/7

egen sop = mean(sophL)
gen sophM = sophL - sop

gen sophH = sophL - 1

// Controls
// [party] 7-point NES measure (0 to 1, mean centered), where higher #'s = more democratic
gen part = 999
replace part = 1 if Q22==1 & Q23==1 
replace part = 2 if Q22==1 & Q23==2
replace part = 3 if Q22==3 & Q25==1
replace part = 3 if Q22==4 & Q25==1
replace part = 4 if Q22==3 & Q25==2
replace part = 4 if Q22==4 & Q25==2
replace part = 5 if Q22==3 & Q25==3
replace part = 5 if Q22==4 & Q25==3
replace part = 6 if Q22==2 & Q24==1
replace part = 7 if Q22==2 & Q24==2
tab part
replace part = . if part==999
sum part, det

gen parti = (part - 1)/6
egen partM = mean(parti)
gen party = parti - partM 
sum party

// [ideology] 7-point NES measure (0 to 1, mean centered), where higher #'s = more liberal
gen ideolog = (Q26 - 1)/6
egen ideologyM = mean(ideolog)
gen ideology = ideolog - ideologyM
sum ideology

// [compint] 4-point Computer Interest (0 to 1, mean centered), where higher #'s = more interest
recode Q20 (1=4)(2=3)(3=2)(4=1), gen (compi)
gen compin = (compi - 1)/3
egen compinM = mean(compin)
gen compint = compin-compinM
sum compint

// [compknow] 4-point Computer Knowledge (0 to 1, mean centered), where higher #'s = more expertise
gen compk = (Q21 - 1)/3
egen compkM = mean(compk)
gen compknow = compk-compkM
sum compknow

// [nnknow] Dummy variable of NN Knowledge, where 1 = knowledge
recode Q1 (2=0), gen(nnknow)

// [educate] 5-point Education Variable
gen educ = (educD - 1)/4
egen educM = mean(educ)
gen educate = educ - educM
sum educate

// [female] Dummy Variable
gen female = 1 if Q27==2
replace female = 0 if Q27==1
sum female

// [nonwhite] Dummy Variabce, where white is the baseline
recode Q31 (1=1)(3=1)(4=0)(5=1), gen(nonwhite)
tab nonwhite

//*** DEPENDENT VARIABLES
alpha Q5 Q6, gen(d1)
gen dv = (d1 - 1)/8
sum dv, det
tab dv

// MEDIATOR
// [quality] Message Quality, 3-item sem. diff. scale
gen q1 = Q7a
//gen q2 = Q8a
gen q3 = Q9a

alpha q1 q3, item

alpha q1 q3, gen(qual)
gen quality = (qual - 1)/8
sum quality, det
tab quality

//*** SUMMARY STATISTICS OF KEY VARIABLES
sum dv quality met lit control sophM party ideology compint compknow nnknow female educate, det
tabstat dv quality met lit control sophM party ideology compint compknow nnknow female educate, statistics (mean sd min max count) col (statistics) long
latabstat dv quality met lit control sophM party ideology compint compknow nnknow female educate, statistics (mean sd min max count) col (statistics) long

sum met if met==1 & dv~=. & sophM~=. & party~=. & ideology~=. & compint~=. & compknow~=. & nnknow~=. & female~=. & educate~=.
sum lit if lit==1 & dv~=. & sophM~=. & party~=. & ideology~=. & compint~=. & compknow~=. & nnknow~=. & female~=. & educate~=.
sum control if control==1 & dv~=. & sophM~=. & party~=. & ideology~=. & compint~=. & compknow~=. & nnknow~=. & female~=. & educate~=.


//*** ANALYSES
// Simple Regression
reg dv lit control sophM educate nnknow compknow compint party ideology female nonwhite

//**Predicted Values
reg dv lit control sophM educate nnknow compknow compint party ideology female nonwhite
prvalue, x(lit=0 control=0 sophM=0 educate=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(lit=1 control=0 sophM=0 educate=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)
prvalue, x(lit=0 control=1 sophM=0 educate=0 nnknow=0 compknow=0 compint=0 party=0 ideology=0 female=0 nonwhite=0)

// Mediation
// by Quality
sgmediation dv, mv(quality) iv(lit) cv(sophM educate nnknow compknow compint party ideology female nonwhite) bootstrap reps(1000) level(95)

// * Sobel Test: http://www.people.ku.edu/~preacher/sobel/sobel.htm
// where a = Reg Coeff b/w IV and MEDIATOR; sa = Standard error of a;
// where b = Reg Coeff b/w MEDIATOR and DV (when IV included); sb = Standard error of b;
// where te = Reg Coeff b/w IV and DV
gen a = -.1372496   
gen sa = .0568596
gen b = .84047
gen sb = .1068038
gen te =  -.1512811

// * Calculate the Sobel test (Z)
gen sobel = (a * b)/(sqrt((b^2 * sa^2) + (a^2 * sb^2) + (sa^2 * sb^2)))
sum sobel

// * Calculate the p-value (of Z)
gen sobelpv = 2*normal(-abs(2.348202))
sum sobelpv

// * Calculate the percentage of the total effect that is mediated
gen totaleff = (a * b)/te
sum totaleff
gen prct = totaleff*100
sum prct

// * Calculate the ratio of the indirect to the direct effect
// Ratio = (a * b)/te
gen ratio = abs(a * b/((a * b)- te))
sum ratio

// Political Sophistication Moderator
gen litXsophL = lit * sophL
gen controlXsophL = control * sophL

gen litXsophM = lit * sophM
gen controlXsophM = control * sophM

gen litXsophH = lit * sophH
gen controlXsophH = control * sophH

reg dv lit control sophL litXsophL controlXsophL educate party ideology compint compknow nnknow female
reg dv lit control sophM litXsophM controlXsophM educate party ideology compint compknow nnknow female
reg dv lit control sophH litXsophH controlXsophH educate party ideology compint compknow nnknow female


//*** GRAPHS with new dataset
use "Study_2_Graph.dta", clear
//  E(dv) |  {res} .6006943     .0570066     .4857896    .7166308
//  E(dv) |  {res} .4554344     .0588747     .3424233    .5719593
//  E(dv) |  {res} .4391867      .053829     .3394922    .5472501

recode treat (1=3)(3=1)

// Basic Graph (Graph Command)
graph bar val, over(treat)
// With Color (Graph)
graph bar val, over(treat) asyvars
// With Error Bars (TwoWay commmand)
graph twoway (bar val treat) (rcap hi95 lo95 treat)
// Create Combined Variable
gen treat2 = 1 if treat == 1
replace  treat2 = 2.5  if treat == 2
replace  treat2 = 4  if treat == 3
// With Error Bars (Twoway)
twoway (bar val treat2) (rcap hi95 lo95 treat2)
// With Legend Labels (Twoway)
twoway (bar val treat2) ///
       (rcap hi95 lo95 treat2), ///
       legend(off) ///
       xlabel( 1 "Metaphor Message" 2.5 "Literal Messaage" 4 "Control Condition", noticks) ///
       xtitle("") ///
       ylabel(0(.15).75) ytitle("Predicted Policy Support")

//findit graph2tex
graph2tex, epsfile(Study2)
